==> paraview_5.7.0.orig.tar.xz: paraview-5.7.0/VTK/ThirdParty/jpeg/vtkjpeg/vtk_jpeg_mangle.h <==
#ifndef VTK_JPEG_MANGLE_H
#define VTK_JPEG_MANGLE_H

#define jcopy_block_row vtkjpeg_jcopy_block_row
#define jcopy_sample_rows vtkjpeg_jcopy_sample_rows
#define jdiv_round_up vtkjpeg_jdiv_round_up
#define jinit_1pass_quantizer vtkjpeg_jinit_1pass_quantizer
#define jinit_2pass_quantizer vtkjpeg_jinit_2pass_quantizer
#define jinit_arith_decoder vtkjpeg_jinit_arith_decoder
#define jinit_arith_encoder vtkjpeg_jinit_arith_encoder
#define jinit_c_coef_controller vtkjpeg_jinit_c_coef_controller
#define jinit_c_main_controller vtkjpeg_jinit_c_main_controller
#define jinit_c_master_control vtkjpeg_jinit_c_master_control
#define jinit_color_converter vtkjpeg_jinit_color_converter
#define jinit_color_deconverter vtkjpeg_jinit_color_deconverter
#define jinit_compress_master vtkjpeg_jinit_compress_master
#define jinit_c_prep_controller vtkjpeg_jinit_c_prep_controller
#define jinit_d_coef_controller vtkjpeg_jinit_d_coef_controller
#define jinit_d_main_controller vtkjpeg_jinit_d_main_controller
#define jinit_downsampler vtkjpeg_jinit_downsampler
#define jinit_d_post_controller vtkjpeg_jinit_d_post_controller
#define jinit_forward_dct vtkjpeg_jinit_forward_dct
#define jinit_huff_decoder vtkjpeg_jinit_huff_decoder
#define jinit_huff_encoder vtkjpeg_jinit_huff_encoder
#define jinit_input_controller vtkjpeg_jinit_input_controller
#define jinit_inverse_dct vtkjpeg_jinit_inverse_dct
#define jinit_marker_reader vtkjpeg_jinit_marker_reader
#define jinit_marker_writer vtkjpeg_jinit_marker_writer
#define jinit_master_decompress vtkjpeg_jinit_master_decompress
#define jinit_memory_mgr vtkjpeg_jinit_memory_mgr
#define jinit_merged_upsampler vtkjpeg_jinit_merged_upsampler
#define jinit_phuff_decoder vtkjpeg_jinit_phuff_decoder
#define jinit_phuff_encoder vtkjpeg_jinit_phuff_encoder
#define jinit_upsampler vtkjpeg_jinit_upsampler
#define jpeg_abort vtkjpeg_jpeg_abort
#define jpeg_abort_compress vtkjpeg_jpeg_abort_compress
#define jpeg_abort_decompress vtkjpeg_jpeg_abort_decompress
#define jpeg_add_quant_table vtkjpeg_jpeg_add_quant_table
#define jpeg_alloc_huff_table vtkjpeg_jpeg_alloc_huff_table
#define jpeg_alloc_quant_table vtkjpeg_jpeg_alloc_quant_table
#define jpeg_aritab vtkjpeg_jpeg_aritab
#define jpeg_calc_jpeg_dimensions vtkjpeg_jpeg_calc_jpeg_dimensions
#define jpeg_calc_output_dimensions vtkjpeg_jpeg_calc_output_dimensions
#define jpeg_consume_input vtkjpeg_jpeg_consume_input
#define jpeg_copy_critical_parameters vtkjpeg_jpeg_copy_critical_parameters
#define jpeg_core_output_dimensions vtkjpeg_jpeg_core_output_dimensions
#define jpeg_CreateCompress vtkjpeg_jpeg_CreateCompress
#define jpeg_CreateDecompress vtkjpeg_jpeg_CreateDecompress
#define jpeg_crop_scanline vtkjpeg_jpeg_crop_scanline
#define jpeg_default_colorspace vtkjpeg_jpeg_default_colorspace
#define jpeg_default_qtables vtkjpeg_jpeg_default_qtables
#define jpeg_destroy vtkjpeg_jpeg_destroy
#define jpeg_destroy_compress vtkjpeg_jpeg_destroy_compress
#define jpeg_destroy_decompress vtkjpeg_jpeg_destroy_decompress
#define jpeg_fdct_float vtkjpeg_jpeg_fdct_float
#define jpeg_fdct_ifast vtkjpeg_jpeg_fdct_ifast
#define jpeg_fdct_islow vtkjpeg_jpeg_fdct_islow
#define jpeg_fill_bit_buffer vtkjpeg_jpeg_fill_bit_buffer
#define jpeg_finish_compress vtkjpeg_jpeg_finish_compress
#define jpeg_finish_decompress vtkjpeg_jpeg_finish_decompress
#define jpeg_finish_output vtkjpeg_jpeg_finish_output
#define jpeg_free_large vtkjpeg_jpeg_free_large
#define jpeg_free_small vtkjpeg_jpeg_free_small
#define jpeg_gen_optimal_table vtkjpeg_jpeg_gen_optimal_table
#define jpeg_get_large vtkjpeg_jpeg_get_large
#define jpeg_get_small vtkjpeg_jpeg_get_small
#define jpeg_has_multiple_scans vtkjpeg_jpeg_has_multiple_scans
#define jpeg_huff_decode vtkjpeg_jpeg_huff_decode
#define jpeg_idct_10x10 vtkjpeg_jpeg_idct_10x10
#define jpeg_idct_11x11 vtkjpeg_jpeg_idct_11x11
#define jpeg_idct_12x12 vtkjpeg_jpeg_idct_12x12
#define jpeg_idct_13x13 vtkjpeg_jpeg_idct_13x13
#define jpeg_idct_14x14 vtkjpeg_jpeg_idct_14x14
#define jpeg_idct_15x15 vtkjpeg_jpeg_idct_15x15
#define jpeg_idct_16x16 vtkjpeg_jpeg_idct_16x16
#define jpeg_idct_1x1 vtkjpeg_jpeg_idct_1x1
#define jpeg_idct_2x2 vtkjpeg_jpeg_idct_2x2
#define jpeg_idct_3x3 vtkjpeg_jpeg_idct_3x3
#define jpeg_idct_4x4 vtkjpeg_jpeg_idct_4x4
#define jpeg_idct_5x5 vtkjpeg_jpeg_idct_5x5
#define jpeg_idct_6x6 vtkjpeg_jpeg_idct_6x6
#define jpeg_idct_7x7 vtkjpeg_jpeg_idct_7x7
#define jpeg_idct_9x9 vtkjpeg_jpeg_idct_9x9
#define jpeg_idct_float vtkjpeg_jpeg_idct_float
#define jpeg_idct_ifast vtkjpeg_jpeg_idct_ifast
#define jpeg_idct_islow vtkjpeg_jpeg_idct_islow
#define jpeg_input_complete vtkjpeg_jpeg_input_complete
#define jpeg_make_c_derived_tbl vtkjpeg_jpeg_make_c_derived_tbl
#define jpeg_make_d_derived_tbl vtkjpeg_jpeg_make_d_derived_tbl
#define jpeg_mem_available vtkjpeg_jpeg_mem_available
#define jpeg_mem_dest vtkjpeg_jpeg_mem_dest
#define jpeg_mem_init vtkjpeg_jpeg_mem_init
#define jpeg_mem_src vtkjpeg_jpeg_mem_src
#define jpeg_mem_term vtkjpeg_jpeg_mem_term
#define jpeg_natural_order vtkjpeg_jpeg_natural_order
#define jpeg_new_colormap vtkjpeg_jpeg_new_colormap
#define jpeg_open_backing_store vtkjpeg_jpeg_open_backing_store
#define jpeg_quality_scaling vtkjpeg_jpeg_quality_scaling
#define jpeg_read_coefficients vtkjpeg_jpeg_read_coefficients
#define jpeg_read_header vtkjpeg_jpeg_read_header
#define jpeg_read_raw_data vtkjpeg_jpeg_read_raw_data
#define jpeg_read_scanlines vtkjpeg_jpeg_read_scanlines
#define jpeg_resync_to_restart vtkjpeg_jpeg_resync_to_restart
#define jpeg_save_markers vtkjpeg_jpeg_save_markers
#define jpeg_set_colorspace vtkjpeg_jpeg_set_colorspace
#define jpeg_set_defaults vtkjpeg_jpeg_set_defaults
#define jpeg_set_linear_quality vtkjpeg_jpeg_set_linear_quality
#define jpeg_set_marker_processor vtkjpeg_jpeg_set_marker_processor
#define jpeg_set_quality vtkjpeg_jpeg_set_quality
#define jpeg_simple_progression vtkjpeg_jpeg_simple_progression
#define jpeg_skip_scanlines vtkjpeg_jpeg_skip_scanlines
#define jpeg_start_compress vtkjpeg_jpeg_start_compress
#define jpeg_start_decompress vtkjpeg_jpeg_start_decompress
#define jpeg_start_output vtkjpeg_jpeg_start_output
#define jpeg_std_error vtkjpeg_jpeg_std_error
#define jpeg_stdio_dest vtkjpeg_jpeg_stdio_dest
#define jpeg_stdio_src vtkjpeg_jpeg_stdio_src
#define jpeg_std_message_table vtkjpeg_jpeg_std_message_table
#define jpeg_suppress_tables vtkjpeg_jpeg_suppress_tables
#define jpeg_write_coefficients vtkjpeg_jpeg_write_coefficients
#define jpeg_write_marker vtkjpeg_jpeg_write_marker
#define jpeg_write_m_byte vtkjpeg_jpeg_write_m_byte
#define jpeg_write_m_header vtkjpeg_jpeg_write_m_header
#define jpeg_write_raw_data vtkjpeg_jpeg_write_raw_data
#define jpeg_write_scanlines vtkjpeg_jpeg_write_scanlines
#define jpeg_write_tables vtkjpeg_jpeg_write_tables
#define jround_up vtkjpeg_jround_up
#define jsimd_can_convsamp vtkjpeg_jsimd_can_convsamp
#define jsimd_can_convsamp_float vtkjpeg_jsimd_can_convsamp_float
#define jsimd_can_fdct_float vtkjpeg_jsimd_can_fdct_float
#define jsimd_can_fdct_ifast vtkjpeg_jsimd_can_fdct_ifast
#define jsimd_can_fdct_islow vtkjpeg_jsimd_can_fdct_islow
#define jsimd_can_h2v1_downsample vtkjpeg_jsimd_can_h2v1_downsample
#define jsimd_can_h2v1_fancy_upsample vtkjpeg_jsimd_can_h2v1_fancy_upsample
#define jsimd_can_h2v1_merged_upsample vtkjpeg_jsimd_can_h2v1_merged_upsample
#define jsimd_can_h2v1_upsample vtkjpeg_jsimd_can_h2v1_upsample
#define jsimd_can_h2v2_downsample vtkjpeg_jsimd_can_h2v2_downsample
#define jsimd_can_h2v2_fancy_upsample vtkjpeg_jsimd_can_h2v2_fancy_upsample
#define jsimd_can_h2v2_merged_upsample vtkjpeg_jsimd_can_h2v2_merged_upsample
#define jsimd_can_h2v2_smooth_downsample vtkjpeg_jsimd_can_h2v2_smooth_downsample
#define jsimd_can_h2v2_upsample vtkjpeg_jsimd_can_h2v2_upsample
#define jsimd_can_huff_encode_one_block vtkjpeg_jsimd_can_huff_encode_one_block
#define jsimd_can_idct_12x12 vtkjpeg_jsimd_can_idct_12x12
#define jsimd_can_idct_2x2 vtkjpeg_jsimd_can_idct_2x2
#define jsimd_can_idct_4x4 vtkjpeg_jsimd_can_idct_4x4
#define jsimd_can_idct_6x6 vtkjpeg_jsimd_can_idct_6x6
#define jsimd_can_idct_float vtkjpeg_jsimd_can_idct_float
#define jsimd_can_idct_ifast vtkjpeg_jsimd_can_idct_ifast
#define jsimd_can_idct_islow vtkjpeg_jsimd_can_idct_islow
#define jsimd_can_int_upsample vtkjpeg_jsimd_can_int_upsample
#define jsimd_can_quantize vtkjpeg_jsimd_can_quantize
#define jsimd_can_quantize_float vtkjpeg_jsimd_can_quantize_float
#define jsimd_can_rgb_gray vtkjpeg_jsimd_can_rgb_gray
#define jsimd_can_rgb_ycc vtkjpeg_jsimd_can_rgb_ycc
#define jsimd_can_ycc_rgb vtkjpeg_jsimd_can_ycc_rgb
#define jsimd_can_ycc_rgb565 vtkjpeg_jsimd_can_ycc_rgb565
#define jsimd_c_can_null_convert vtkjpeg_jsimd_c_can_null_convert
#define jsimd_c_null_convert vtkjpeg_jsimd_c_null_convert
#define jsimd_convsamp vtkjpeg_jsimd_convsamp
#define jsimd_convsamp_float vtkjpeg_jsimd_convsamp_float
#define jsimd_fdct_float vtkjpeg_jsimd_fdct_float
#define jsimd_fdct_ifast vtkjpeg_jsimd_fdct_ifast
#define jsimd_fdct_islow vtkjpeg_jsimd_fdct_islow
#define jsimd_h2v1_downsample vtkjpeg_jsimd_h2v1_downsample
#define jsimd_h2v1_fancy_upsample vtkjpeg_jsimd_h2v1_fancy_upsample
#define jsimd_h2v1_merged_upsample vtkjpeg_jsimd_h2v1_merged_upsample
#define jsimd_h2v1_upsample vtkjpeg_jsimd_h2v1_upsample
#define jsimd_h2v2_downsample vtkjpeg_jsimd_h2v2_downsample
#define jsimd_h2v2_fancy_upsample vtkjpeg_jsimd_h2v2_fancy_upsample
#define jsimd_h2v2_merged_upsample vtkjpeg_jsimd_h2v2_merged_upsample
#define jsimd_h2v2_smooth_downsample vtkjpeg_jsimd_h2v2_smooth_downsample
#define jsimd_h2v2_upsample vtkjpeg_jsimd_h2v2_upsample
#define jsimd_huff_encode_one_block vtkjpeg_jsimd_huff_encode_one_block
#define jsimd_idct_12x12 vtkjpeg_jsimd_idct_12x12
#define jsimd_idct_2x2 vtkjpeg_jsimd_idct_2x2
#define jsimd_idct_4x4 vtkjpeg_jsimd_idct_4x4
#define jsimd_idct_6x6 vtkjpeg_jsimd_idct_6x6
#define jsimd_idct_float vtkjpeg_jsimd_idct_float
#define jsimd_idct_ifast vtkjpeg_jsimd_idct_ifast
#define jsimd_idct_islow vtkjpeg_jsimd_idct_islow
#define jsimd_int_upsample vtkjpeg_jsimd_int_upsample
#define jsimd_quantize vtkjpeg_jsimd_quantize
#define jsimd_quantize_float vtkjpeg_jsimd_quantize_float
#define jsimd_rgb_gray_convert vtkjpeg_jsimd_rgb_gray_convert
#define jsimd_rgb_ycc_convert vtkjpeg_jsimd_rgb_ycc_convert
#define jsimd_ycc_rgb565_convert vtkjpeg_jsimd_ycc_rgb565_convert
#define jsimd_ycc_rgb_convert vtkjpeg_jsimd_ycc_rgb_convert
#define jzero_far vtkjpeg_jzero_far

#endif

==> paraview_5.9.0.orig.tar.xz: paraview-5.9.0/VTK/ThirdParty/jpeg/vtkjpeg/vtk_jpeg_mangle.h <==
#ifndef VTK_JPEG_MANGLE_H
#define VTK_JPEG_MANGLE_H

#define jcopy_block_row vtkjpeg_jcopy_block_row
#define jcopy_sample_rows vtkjpeg_jcopy_sample_rows
#define jdiv_round_up vtkjpeg_jdiv_round_up
#define jinit_1pass_quantizer vtkjpeg_jinit_1pass_quantizer
#define jinit_2pass_quantizer vtkjpeg_jinit_2pass_quantizer
#define jinit_arith_decoder vtkjpeg_jinit_arith_decoder
#define jinit_arith_encoder vtkjpeg_jinit_arith_encoder
#define jinit_c_coef_controller vtkjpeg_jinit_c_coef_controller
#define jinit_c_main_controller vtkjpeg_jinit_c_main_controller
#define jinit_c_master_control vtkjpeg_jinit_c_master_control
#define jinit_color_converter vtkjpeg_jinit_color_converter
#define jinit_color_deconverter vtkjpeg_jinit_color_deconverter
#define jinit_compress_master vtkjpeg_jinit_compress_master
#define jinit_c_prep_controller vtkjpeg_jinit_c_prep_controller
#define jinit_d_coef_controller vtkjpeg_jinit_d_coef_controller
#define jinit_d_main_controller vtkjpeg_jinit_d_main_controller
#define jinit_downsampler vtkjpeg_jinit_downsampler
#define jinit_d_post_controller vtkjpeg_jinit_d_post_controller
#define jinit_forward_dct vtkjpeg_jinit_forward_dct
#define jinit_huff_decoder vtkjpeg_jinit_huff_decoder
#define jinit_huff_encoder vtkjpeg_jinit_huff_encoder
#define jinit_input_controller vtkjpeg_jinit_input_controller
#define jinit_inverse_dct vtkjpeg_jinit_inverse_dct
#define jinit_marker_reader vtkjpeg_jinit_marker_reader
#define jinit_marker_writer vtkjpeg_jinit_marker_writer
#define jinit_master_decompress vtkjpeg_jinit_master_decompress
#define jinit_memory_mgr vtkjpeg_jinit_memory_mgr
#define jinit_merged_upsampler vtkjpeg_jinit_merged_upsampler
#define jinit_phuff_decoder vtkjpeg_jinit_phuff_decoder
#define jinit_phuff_encoder vtkjpeg_jinit_phuff_encoder
#define jinit_upsampler vtkjpeg_jinit_upsampler
#define jpeg_abort vtkjpeg_jpeg_abort
#define jpeg_abort_compress vtkjpeg_jpeg_abort_compress
#define jpeg_abort_decompress vtkjpeg_jpeg_abort_decompress
#define jpeg_add_quant_table vtkjpeg_jpeg_add_quant_table
#define jpeg_alloc_huff_table vtkjpeg_jpeg_alloc_huff_table
#define jpeg_alloc_quant_table vtkjpeg_jpeg_alloc_quant_table
#define jpeg_aritab vtkjpeg_jpeg_aritab
#define jpeg_calc_jpeg_dimensions vtkjpeg_jpeg_calc_jpeg_dimensions
#define jpeg_calc_output_dimensions vtkjpeg_jpeg_calc_output_dimensions
#define jpeg_consume_input vtkjpeg_jpeg_consume_input
#define jpeg_copy_critical_parameters vtkjpeg_jpeg_copy_critical_parameters
#define jpeg_core_output_dimensions vtkjpeg_jpeg_core_output_dimensions
#define jpeg_CreateCompress vtkjpeg_jpeg_CreateCompress
#define jpeg_CreateDecompress vtkjpeg_jpeg_CreateDecompress
#define jpeg_crop_scanline vtkjpeg_jpeg_crop_scanline
#define jpeg_default_colorspace vtkjpeg_jpeg_default_colorspace
#define jpeg_default_qtables vtkjpeg_jpeg_default_qtables
#define jpeg_destroy vtkjpeg_jpeg_destroy
#define jpeg_destroy_compress vtkjpeg_jpeg_destroy_compress
#define jpeg_destroy_decompress vtkjpeg_jpeg_destroy_decompress
#define jpeg_fdct_float vtkjpeg_jpeg_fdct_float
#define jpeg_fdct_ifast vtkjpeg_jpeg_fdct_ifast
#define jpeg_fdct_islow vtkjpeg_jpeg_fdct_islow
#define jpeg_fill_bit_buffer vtkjpeg_jpeg_fill_bit_buffer
#define jpeg_finish_compress vtkjpeg_jpeg_finish_compress
#define jpeg_finish_decompress vtkjpeg_jpeg_finish_decompress
#define jpeg_finish_output vtkjpeg_jpeg_finish_output
#define jpeg_free_large vtkjpeg_jpeg_free_large
#define jpeg_free_small vtkjpeg_jpeg_free_small
#define jpeg_gen_optimal_table vtkjpeg_jpeg_gen_optimal_table
#define jpeg_get_large vtkjpeg_jpeg_get_large
#define jpeg_get_small vtkjpeg_jpeg_get_small
#define jpeg_has_multiple_scans vtkjpeg_jpeg_has_multiple_scans
#define jpeg_huff_decode vtkjpeg_jpeg_huff_decode
#define jpeg_idct_10x10 vtkjpeg_jpeg_idct_10x10
#define jpeg_idct_11x11 vtkjpeg_jpeg_idct_11x11
#define jpeg_idct_12x12 vtkjpeg_jpeg_idct_12x12
#define jpeg_idct_13x13 vtkjpeg_jpeg_idct_13x13
#define jpeg_idct_14x14 vtkjpeg_jpeg_idct_14x14
#define jpeg_idct_15x15 vtkjpeg_jpeg_idct_15x15
#define jpeg_idct_16x16 vtkjpeg_jpeg_idct_16x16
#define jpeg_idct_1x1 vtkjpeg_jpeg_idct_1x1
#define jpeg_idct_2x2 vtkjpeg_jpeg_idct_2x2
#define jpeg_idct_3x3 vtkjpeg_jpeg_idct_3x3
#define jpeg_idct_4x4 vtkjpeg_jpeg_idct_4x4
#define jpeg_idct_5x5 vtkjpeg_jpeg_idct_5x5
#define jpeg_idct_6x6 vtkjpeg_jpeg_idct_6x6
#define jpeg_idct_7x7 vtkjpeg_jpeg_idct_7x7
#define jpeg_idct_9x9 vtkjpeg_jpeg_idct_9x9
#define jpeg_idct_float vtkjpeg_jpeg_idct_float
#define jpeg_idct_ifast vtkjpeg_jpeg_idct_ifast
#define jpeg_idct_islow vtkjpeg_jpeg_idct_islow
#define jpeg_input_complete vtkjpeg_jpeg_input_complete
#define jpeg_make_c_derived_tbl vtkjpeg_jpeg_make_c_derived_tbl
#define jpeg_make_d_derived_tbl vtkjpeg_jpeg_make_d_derived_tbl
#define jpeg_mem_available vtkjpeg_jpeg_mem_available
#define jpeg_mem_dest vtkjpeg_jpeg_mem_dest
#define jpeg_mem_init vtkjpeg_jpeg_mem_init
#define jpeg_mem_src vtkjpeg_jpeg_mem_src
#define jpeg_mem_term vtkjpeg_jpeg_mem_term
#define jpeg_natural_order vtkjpeg_jpeg_natural_order
#define jpeg_new_colormap vtkjpeg_jpeg_new_colormap
#define jpeg_open_backing_store vtkjpeg_jpeg_open_backing_store
#define jpeg_quality_scaling vtkjpeg_jpeg_quality_scaling
#define jpeg_read_coefficients vtkjpeg_jpeg_read_coefficients
#define jpeg_read_header vtkjpeg_jpeg_read_header
#define jpeg_read_icc_profile vtkjpeg_jpeg_read_icc_profile
#define jpeg_read_raw_data vtkjpeg_jpeg_read_raw_data
#define jpeg_read_scanlines vtkjpeg_jpeg_read_scanlines
#define jpeg_resync_to_restart vtkjpeg_jpeg_resync_to_restart
#define jpeg_save_markers vtkjpeg_jpeg_save_markers
#define jpeg_set_colorspace vtkjpeg_jpeg_set_colorspace
#define jpeg_set_defaults vtkjpeg_jpeg_set_defaults
#define jpeg_set_linear_quality vtkjpeg_jpeg_set_linear_quality
#define jpeg_set_marker_processor vtkjpeg_jpeg_set_marker_processor
#define jpeg_set_quality vtkjpeg_jpeg_set_quality
#define jpeg_simple_progression vtkjpeg_jpeg_simple_progression
#define jpeg_skip_scanlines vtkjpeg_jpeg_skip_scanlines
#define jpeg_start_compress vtkjpeg_jpeg_start_compress
#define jpeg_start_decompress vtkjpeg_jpeg_start_decompress
#define jpeg_start_output vtkjpeg_jpeg_start_output
#define jpeg_std_error vtkjpeg_jpeg_std_error
#define jpeg_stdio_dest vtkjpeg_jpeg_stdio_dest
#define jpeg_stdio_src vtkjpeg_jpeg_stdio_src
#define jpeg_std_message_table vtkjpeg_jpeg_std_message_table
#define jpeg_suppress_tables vtkjpeg_jpeg_suppress_tables
#define jpeg_write_coefficients vtkjpeg_jpeg_write_coefficients
#define jpeg_write_icc_profile vtkjpeg_jpeg_write_icc_profile
#define jpeg_write_marker vtkjpeg_jpeg_write_marker
#define jpeg_write_m_byte vtkjpeg_jpeg_write_m_byte
#define jpeg_write_m_header vtkjpeg_jpeg_write_m_header
#define jpeg_write_raw_data vtkjpeg_jpeg_write_raw_data
#define jpeg_write_scanlines vtkjpeg_jpeg_write_scanlines
#define jpeg_write_tables vtkjpeg_jpeg_write_tables
#define jround_up vtkjpeg_jround_up
#define jsimd_can_convsamp vtkjpeg_jsimd_can_convsamp
#define jsimd_can_convsamp_float vtkjpeg_jsimd_can_convsamp_float
#define jsimd_can_encode_mcu_AC_first_prepare vtkjpeg_jsimd_can_encode_mcu_AC_first_prepare
#define jsimd_can_encode_mcu_AC_refine_prepare vtkjpeg_jsimd_can_encode_mcu_AC_refine_prepare
#define jsimd_can_fdct_float vtkjpeg_jsimd_can_fdct_float
#define jsimd_can_fdct_ifast vtkjpeg_jsimd_can_fdct_ifast
#define jsimd_can_fdct_islow vtkjpeg_jsimd_can_fdct_islow
#define jsimd_can_h2v1_downsample vtkjpeg_jsimd_can_h2v1_downsample
#define jsimd_can_h2v1_fancy_upsample vtkjpeg_jsimd_can_h2v1_fancy_upsample
#define jsimd_can_h2v1_merged_upsample vtkjpeg_jsimd_can_h2v1_merged_upsample
#define jsimd_can_h2v1_upsample vtkjpeg_jsimd_can_h2v1_upsample
#define jsimd_can_h2v2_downsample vtkjpeg_jsimd_can_h2v2_downsample
#define jsimd_can_h2v2_fancy_upsample vtkjpeg_jsimd_can_h2v2_fancy_upsample
#define jsimd_can_h2v2_merged_upsample vtkjpeg_jsimd_can_h2v2_merged_upsample
#define jsimd_can_h2v2_smooth_downsample vtkjpeg_jsimd_can_h2v2_smooth_downsample
#define jsimd_can_h2v2_upsample vtkjpeg_jsimd_can_h2v2_upsample
#define jsimd_can_huff_encode_one_block vtkjpeg_jsimd_can_huff_encode_one_block
#define jsimd_can_idct_12x12 vtkjpeg_jsimd_can_idct_12x12
#define jsimd_can_idct_2x2 vtkjpeg_jsimd_can_idct_2x2
#define jsimd_can_idct_4x4 vtkjpeg_jsimd_can_idct_4x4
#define jsimd_can_idct_6x6 vtkjpeg_jsimd_can_idct_6x6
#define jsimd_can_idct_float vtkjpeg_jsimd_can_idct_float
#define jsimd_can_idct_ifast vtkjpeg_jsimd_can_idct_ifast
#define jsimd_can_idct_islow vtkjpeg_jsimd_can_idct_islow
#define jsimd_can_int_upsample vtkjpeg_jsimd_can_int_upsample
#define jsimd_can_quantize vtkjpeg_jsimd_can_quantize
#define jsimd_can_quantize_float vtkjpeg_jsimd_can_quantize_float
#define jsimd_can_rgb_gray vtkjpeg_jsimd_can_rgb_gray
#define jsimd_can_rgb_ycc vtkjpeg_jsimd_can_rgb_ycc
#define jsimd_can_ycc_rgb vtkjpeg_jsimd_can_ycc_rgb
#define jsimd_can_ycc_rgb565 vtkjpeg_jsimd_can_ycc_rgb565
#define jsimd_c_can_null_convert vtkjpeg_jsimd_c_can_null_convert
#define jsimd_c_null_convert vtkjpeg_jsimd_c_null_convert
#define jsimd_convsamp vtkjpeg_jsimd_convsamp
#define jsimd_convsamp_float vtkjpeg_jsimd_convsamp_float
#define jsimd_encode_mcu_AC_first_prepare vtkjpeg_jsimd_encode_mcu_AC_first_prepare
#define jsimd_encode_mcu_AC_refine_prepare vtkjpeg_jsimd_encode_mcu_AC_refine_prepare
#define jsimd_fdct_float vtkjpeg_jsimd_fdct_float
#define jsimd_fdct_ifast vtkjpeg_jsimd_fdct_ifast
#define jsimd_fdct_islow vtkjpeg_jsimd_fdct_islow
#define jsimd_h2v1_downsample vtkjpeg_jsimd_h2v1_downsample
#define jsimd_h2v1_fancy_upsample vtkjpeg_jsimd_h2v1_fancy_upsample
#define jsimd_h2v1_merged_upsample vtkjpeg_jsimd_h2v1_merged_upsample
#define jsimd_h2v1_upsample vtkjpeg_jsimd_h2v1_upsample
#define jsimd_h2v2_downsample vtkjpeg_jsimd_h2v2_downsample
#define jsimd_h2v2_fancy_upsample vtkjpeg_jsimd_h2v2_fancy_upsample
#define jsimd_h2v2_merged_upsample vtkjpeg_jsimd_h2v2_merged_upsample
#define jsimd_h2v2_smooth_downsample vtkjpeg_jsimd_h2v2_smooth_downsample
#define jsimd_h2v2_upsample vtkjpeg_jsimd_h2v2_upsample
#define jsimd_huff_encode_one_block vtkjpeg_jsimd_huff_encode_one_block
#define jsimd_idct_12x12 vtkjpeg_jsimd_idct_12x12
#define jsimd_idct_2x2 vtkjpeg_jsimd_idct_2x2
#define jsimd_idct_4x4 vtkjpeg_jsimd_idct_4x4
#define jsimd_idct_6x6 vtkjpeg_jsimd_idct_6x6
#define jsimd_idct_float vtkjpeg_jsimd_idct_float
#define jsimd_idct_ifast vtkjpeg_jsimd_idct_ifast
#define jsimd_idct_islow vtkjpeg_jsimd_idct_islow
#define jsimd_int_upsample vtkjpeg_jsimd_int_upsample
#define jsimd_quantize vtkjpeg_jsimd_quantize
#define jsimd_quantize_float vtkjpeg_jsimd_quantize_float
#define jsimd_rgb_gray_convert vtkjpeg_jsimd_rgb_gray_convert
#define jsimd_rgb_ycc_convert vtkjpeg_jsimd_rgb_ycc_convert
#define jsimd_ycc_rgb565_convert vtkjpeg_jsimd_ycc_rgb565_convert
#define jsimd_ycc_rgb_convert vtkjpeg_jsimd_ycc_rgb_convert
#define jzero_far vtkjpeg_jzero_far

#endif
